<?php declare(strict_types=1);

use BitBadger\PDODocument\{AutoId, Configuration, Custom, Definition, Document, Mode};
use BitBadger\PDODocument\Mapper\ArrayMapper;
use MyPrayerJournal\Domain\{History, Note, Recurrence, RecurrencePeriod, Request, RequestAction};
use MyPrayerJournal\Table;

require 'start.php';

echo 'Retrieving v3 requests...' . PHP_EOL;

Configuration::resetPDO();
Configuration::useDSN('pgsql:host=localhost;user=mpj;password=devpassword;dbname=mpj');
$reqs = Custom::array('SELECT data FROM mpj.request', [], new ArrayMapper());

echo 'Found ' . sizeof($reqs) . ' requests; migrating to v4...' . PHP_EOL;

Configuration::resetPDO();
Configuration::useDSN('sqlite:./data/mpj.db');
Configuration::$autoId         = AutoId::RandomString;
Configuration::$idStringLength = 12;

Definition::ensureTable(Table::REQUEST);

/** Convert dates to the same format */
function convertDate(string $date): string
{
    return new DateTimeImmutable($date)->format('c');
}

foreach ($reqs as $reqJson) {
    $req         = json_decode($reqJson['data']);
    $recurParts  = explode(' ', $req->recurrence);
    $recurPeriod = RecurrencePeriod::from(end($recurParts));
    $recur       = match ($recurPeriod) {
        RecurrencePeriod::Immediate => new Recurrence(RecurrencePeriod::Immediate),
        default                     => new Recurrence($recurPeriod, (int)$recurParts[0])
    };
    Document::insert(Table::REQUEST, new Request(
        enteredOn:    convertDate($req->enteredOn),
        userId:       $req->userId,
        snoozedUntil: property_exists($req, 'snoozedUntil') ? convertDate($req->snoozedUntil) : null,
        showAfter:    property_exists($req, 'showAfter')    ? convertDate($req->showAfter)    : null,
        recurrence:   $recur,
        history:      array_map(fn(stdClass $hist) =>
                          new History(
                              asOf:   convertDate($hist->asOf),
                              action: RequestAction::from($hist->status),
                              text:   property_exists($hist, 'text') ? $hist->text : null),
                          $req->history),
        notes:        array_map(fn(stdClass $note) =>
                          new Note(convertDate($note->asOf), $note->notes), $req->notes ?? [])));
}

echo PHP_EOL . 'done' . PHP_EOL;
