<?php
/**
 * @author Daniel J. Summers <daniel@bitbadger.solutions>
 * @license MIT
 */

declare(strict_types=1);

namespace MyPrayerJournal\Domain;

use BitBadger\InspiredByFSharp\Option;
use BitBadger\PDODocument\DocumentException;
use Square\Pjson\{Json, JsonSerialize};

/**
 * A note entered on a prayer request
 */
class Note
{
    use JsonSerialize;

    /**
     * @param string $asOf The date/time this note was recorded
     * @param string $text The text of the note
     */
    public function __construct(#[Json] public string $asOf, #[Json] public string $text) { }

    /**
     * Retrieve notes for a given request
     *
     * @param string $id The ID of the request for which notes should be retrieved
     * @return array|Note[] The notes for the request, or an empty array if the request was not found
     * @throws DocumentException If any is encountered
     */
    public static function byRequestId(string $id): array
    {
        return Request::byId($id)->map(fn(Request $it) => Option::Some($it->notes))->getOrDefault([]);
    }
}
