<?php
/**
 * @author Daniel J. Summers <daniel@bitbadger.solutions>
 * @license MIT
 */

declare(strict_types=1);

use MyPrayerJournal\UI\Layout;

require '../start.php';
if ($_SERVER['REQUEST_METHOD'] <> 'GET') not_found();

Layout::pageHead('Documentation'); ?>
<article class="container mt-3">
    <h2 class=mb-3>Documentation</h2>

    <h3 class="mb-3 mt-4">About myPrayerJournal</h3>
    <p>Journaling has a long history; it helps people remember what happened, and the act of writing helps people think
        about what happened and process it. A prayer journal is not a new concept; it helps you keep track of the
        requests for which you&rsquo;ve prayed, you can use it to pray over things repeatedly, and you can write the
        result when the answer comes <em>(or it was &ldquo;no&rdquo;)</em>.
    <p>myPrayerJournal was borne of out of a personal desire
        <a href=https://daniel.summershome.org target=_blank rel=noopener>Daniel</a> had to have something that would
        help him with his prayer life. When it&rsquo;s time to pray, it&rsquo;s not really time to use an app, so the
        design goal here is to keep it simple and unobtrusive. It will also help eliminate some of the downsides to a
        paper prayer journal, like not remembering whether you&rsquo;ve prayed for a request, or running out of room to
        write another update on one.

    <h3 class="mb-3 mt-4">Signing Up</h3>
    <p>myPrayerJournal uses login services using Google or Microsoft accounts. The only information the application
        stores in its database is your user ID token it receives from these services, so there are no permissions you
        should have to accept from these provider other than establishing that you can log on with that account. Because
        of this, you&rsquo;ll want to pick the same one each time; the tokens between the two accounts are different,
        even if you use the same e-mail address to log on to both.

    <h3 class="mb-3 mt-4">Your Prayer Journal</h3>
    <p>Your current requests will be presented in columns (usually three, but it could be more or less, depending on the
        size of your screen or device). Each request is in its own card, and the buttons at the top of each card apply
        to that request. The last line of each request also tells you how long it has been since anything has been done
        on that request. Any time you see something like &ldquo;a few minutes ago,&rdquo; you can hover over that to see
        the actual date/time the action was taken.

    <h3 class="mb-3 mt-4">Adding a Request</h3>
    <p>To add a request, click the &ldquo;Add a New Request&rdquo; button at the top of your journal. Then, enter the
        text of the request as you see fit; there is no right or wrong way, and you are the only person who will see the
        text you enter. When you save the request, it will go to the bottom of the list of requests.

    <h3 class="mb-3 mt-4">Setting Request Recurrence</h3>
    <p>When you add or update a request, you can choose whether requests go to the bottom of the journal once they have
        been marked &ldquo;Prayed&rdquo; or whether they will reappear after a delay. You can set recurrence in terms of
        hours, days, or weeks, but it cannot be longer than 365 days. If you decide you want a request to reappear
        sooner, you can skip the current delay; click the &ldquo;Active&rdquo; menu link, find the request in the list
        (likely near the bottom), and click the &ldquo;Show Now&rdquo; button.

    <h3 class="mb-3 mt-4">Praying for Requests</h3>
    <p>The first button for each request has a checkmark icon; clicking this button will mark the request as
        &ldquo;Prayed&rdquo; and move it to the bottom of the list (or off, if you&rsquo;ve set a recurrence period for
        the request). This allows you, if you&rsquo;re praying through your requests, to start at the top left (with the
        request that it&rsquo;s been the longest since you&rsquo;ve prayed) and click the button as you pray; when the
        request move below or away, the next-least-recently-prayed request will take the top spot.

    <h3 class="mb-3 mt-4">Editing Requests</h3>
    <p>The second button for each request has a pencil icon. This allows you to edit the text of the request, pretty
        much the same way you entered it; it starts with the current text, and you can add to it, modify it, or
        completely replace it. By default, updates will go in with an &ldquo;Updated&rdquo; status; you have the option
        to also mark this update as &ldquo;Prayed&rdquo; or &ldquo;Answered&rdquo;. Answered requests will drop off the
        journal list.

    <h3 class="mb-3 mt-4">Adding Notes</h3>
    <p>The third button for each request has an icon that looks like a speech bubble with lines on it; this lets you
        record notes about the request. If there is something you want to record that doesn&rsquo;t change the text of
        the request, this is the place to do it. For example, you may be praying for a long-term health issue, and that
        person tells you that their status is the same; or, you may want to record something God said to you while you
        were praying for that request."

    <h3 class="mb-3 mt-4">Snoozing Requests</h3>
    <p>There may be a time when a request does not need to appear. The fourth button, with the clock icon, allows you to
        snooze requests until the day you specify. Additionally, if you have any snoozed requests, a
        &ldquo;Snoozed&rdquo; menu item will appear next to the &ldquo;Journal&rdquo; one; this page allows you to see
        what requests are snoozed, and return them to your journal by canceling the snooze.

    <h3 class="mb-3 mt-4">Viewing a Request and Its History</h3>
    <p>myPrayerJournal tracks all actions related to a request; from the &ldquo;Active&rdquo; and &ldquo;Answered&rdquo;
        menu links (and &ldquo;Snoozed&rdquo;, if it&rsquo;s showing), there is a &ldquo;View Full Request&rdquo;
        button. That page will show the current text of the request; how many times it has been marked as prayed; how
        long it has been an active request; and a log of all updates, prayers, and notes you have recorded. That log is
        listed from most recent to least recent; if you want to read it chronologically, press the &ldquo;End&rdquo; key
        on your keyboard and read it from the bottom up.
    <p>The &ldquo;Active&rdquo; link will show all requests that have not yet been marked answered, including snoozed
        and recurring requests. If requests are snoozed, or in a recurrence period off the journal, there will be a
        button where you can return the request to the list (either &ldquo;Cancel Snooze&rdquo; or &ldquo;Show
        Now&rdquo;). The &ldquo;Answered&rdquo; link shows all requests that have been marked answered. The
        &ldquo;Snoozed&rdquo; link only shows snoozed requests.

    <h3 id=notes class="mb-3 mt-4">Final Notes</h3>
    <ul>
        <li>If you encounter errors, please
            <a href=https://git.bitbadger.solutions/bit-badger/myPrayerJournal/issues target=_blank rel=noopener>file an
            issue</a> (or <a href="mailto:daniel@bitbadger.solutions?subject=myPrayerJournal+Issue">e-mail Daniel</a> if
            you do not have an account on that server) with as much detail as possible. You can also provide
            suggestions, or browse the list of currently open issues.
        <li>Prayer requests and their history are securely backed up nightly along with other Bit Badger Solutions data.
        <li>Prayer changes things - most of all, the one doing the praying. I pray that this tool enables you to deepen
            and strengthen your prayer life.
    </ul>
</article><?php
Layout::pageFoot();
